@@ -64,6 +64,52 @@
 #define DEFAULT_ROOT_PROFILE	"server"
 #define MAX_INCLUDE_LEVEL 6		// include levels in profile files
 
+#define ASSERT_PERMS(file, uid, gid, mode) \
+	do { \
+		assert(file);\
+		struct stat s;\
+		if (stat(file, &s) == -1) errExit("stat");\
+		assert(s.st_uid == uid);\
+		assert(s.st_gid == gid);\
+		assert((s.st_mode & 07777) == (mode));\
+	} while (0)
+#define ASSERT_PERMS_FD(fd, uid, gid, mode) \
+	do { \
+		struct stat s;\
+		if (fstat(fd, &s) == -1) errExit("stat");\
+		assert(s.st_uid == uid);\
+		assert(s.st_gid == gid);\
+		assert((s.st_mode & 07777) == (mode));\
+	} while (0)
+#define ASSERT_PERMS_STREAM(file, uid, gid, mode) \
+	do { \
+		int fd = fileno(file);\
+		if (fd == -1) errExit("fileno");\
+		ASSERT_PERMS_FD(fd, uid, gid, (mode));\
+	} while (0)
+
+#define SET_PERMS_FD(fd, uid, gid, mode) \
+	do { \
+		if (fchmod(fd, (mode)) == -1)	errExit("chmod");\
+		if (fchown(fd, uid, gid) == -1) errExit("chown");\
+	} while (0)
+#define SET_PERMS_STREAM(stream, uid, gid, mode) \
+	do { \
+		int fd = fileno(stream);\
+		if (fd == -1) errExit("fileno");\
+		SET_PERMS_FD(fd, uid, gid, (mode));\
+	} while (0)
+#define SET_PERMS_STREAM_NOERR(stream, uid, gid, mode) \
+	do { \
+		int fd = fileno(stream);\
+		if (fd == -1) continue;\
+		int rv = fchmod(fd, (mode));\
+		(void) rv;\
+		rv = fchown(fd, uid, gid);\
+		(void) rv;\
+	} while (0)
+
+
 // main.c
 typedef struct bridge_t {
 	// on the host
@@ -287,7 +333,7 @@ void fs_basic_fs(void);
 void fs_overlayfs(void);
 // chroot into an existing directory; mount exiting /dev and update /etc/resolv.conf
 void fs_chroot(const char *rootdir);
-int fs_check_chroot_dir(const char *rootdir);
+void fs_check_chroot_dir(const char *rootdir);
 void fs_private_tmp(void);
 
 // profile.c
@@ -343,6 +389,8 @@ void logmsg(const char *msg);
 void logargs(int argc, char **argv) ;
 void logerr(const char *msg);
 int copy_file(const char *srcname, const char *destname);
+void copy_file_as_user(const char *srcname, const char *destname, uid_t uid, gid_t gid, mode_t mode);
+void touch_file_as_user(const char *fname, uid_t uid, gid_t gid, mode_t mode);
 int is_dir(const char *fname);
 int is_link(const char *fname);
 char *line_remove_spaces(const char *buf);
@@ -357,6 +405,8 @@ char *expand_home(const char *path, const char* homedir);
 const char *gnu_basename(const char *path);
 uid_t pid_get_uid(pid_t pid);
 void invalid_filename(const char *fname);
+int remove_directory(const char *path);
+void flush_stdin(void);
 
 // fs_var.c
 void fs_var_log(void);	// mounting /var/log
