@@ -29,6 +29,12 @@ static uint64_t caps = 0;
 static int apply_seccomp = 0;
 #define BUFLEN 4096
 
+static void signal_handler(int sig){
+	flush_stdin();
+
+	exit(sig);
+}
+
 static void extract_command(int argc, char **argv, int index) {
 	if (index >= argc)
 		return;
@@ -194,6 +200,7 @@ void join_name(const char *name, const char *homedir, int argc, char **argv, int
 
 void join(pid_t pid, const char *homedir, int argc, char **argv, int index) {
 	extract_command(argc, argv, index);
+	signal (SIGTERM, signal_handler);
 
 	// if the pid is that of a firejail  process, use the pid of the first child process
 	char *comm = pid_proc_comm(pid);
@@ -388,6 +395,7 @@ void join(pid_t pid, const char *homedir, int argc, char **argv, int index) {
 
 	// wait for the child to finish
 	waitpid(child, NULL, 0);
+	flush_stdin();
 	exit(0);
 }
 
