@@ -111,6 +111,7 @@ static void myexit(int rv) {
 	bandwidth_shm_del_file(sandbox_pid);		// bandwidth file
 	network_shm_del_file(sandbox_pid);		// network map file
 	
+	flush_stdin();
 	exit(rv); 
 }
 
@@ -178,7 +179,8 @@ static int read_pid(char *str, pid_t *pid) {
 		|| (errno != 0 && pidtmp == 0)) {
 		return 1;
 	}
-	if (endptr == str) {
+	// endptr points to '\0' char in str if the entire string is valid
+	if (endptr == NULL || endptr[0]!='\0') {
 		return 1;
 	}
 	*pid = (pid_t)pidtmp;
@@ -245,6 +247,21 @@ static void run_cmd_and_exit(int i, int argc, char **argv) {
 		printf("firejail version %s\n", VERSION);
 		exit(0);
 	}
+	else if (strcmp(argv[i], "--overlay-clean") == 0) {
+		char *path;
+		if (asprintf(&path, "%s/.firejail", cfg.homedir) == -1)
+			errExit("asprintf");
+		if (setreuid(0, 0) < 0)
+			errExit("setreuid");
+		if (setregid(0, 0) < 0)
+			errExit("setregid");
+		errno = 0;
+		int rv = remove_directory(path);
+		if (rv) {
+			fprintf(stderr, "Error: cannot removed overlays stored in ~/.firejail directory, errno %d\n", errno);
+			exit(1);
+		}
+	}
 #ifdef HAVE_NETWORK	
 	else if (strncmp(argv[i], "--bandwidth=", 12) == 0) {
 		logargs(argc, argv);
@@ -868,6 +885,14 @@ int main(int argc, char **argv) {
 				fprintf(stderr, "Error: --overlay and --chroot options are mutually exclusive\n");
 				exit(1);
 			}
+			
+			struct stat s;
+			if (stat("/proc/sys/kernel/grsecurity", &s) == 0) {
+				fprintf(stderr, "Error: --chroot option is not available on Grsecurity systems\n");
+				exit(1);	
+			}
+			
+			
 			invalid_filename(argv[i] + 9);
 			
 			// extract chroot dirname
@@ -886,11 +911,16 @@ int main(int argc, char **argv) {
 				return 1;
 			}
 			
-			// check chroot directory structure
-			if (fs_check_chroot_dir(cfg.chrootdir)) {
-				fprintf(stderr, "Error: invalid chroot\n");
+			// don't allow "--chroot=/"
+			char *rpath = realpath(cfg.chrootdir, NULL);
+			if (rpath == NULL || strcmp(rpath, "/") == 0) {
+				fprintf(stderr, "Error: invalid chroot directory\n");
 				exit(1);
 			}
+			cfg.chrootdir = rpath;
+			
+			// check chroot directory structure
+			fs_check_chroot_dir(cfg.chrootdir);
 		}
 #endif
 		else if (strcmp(argv[i], "--private") == 0)
