@@ -171,35 +171,18 @@ static void monitor_application(pid_t app_pid) {
 			printf("Sandbox monitor: monitoring %u\n", app_pid);
 	}
 
-#if 0
-// todo: find a way to shut down interfaces before closing the namespace
-// the problem is we don't have enough privileges to shutdown interfaces in this moment
-	// shut down bridge/macvlan interfaces
-	if (any_bridge_configured()) {
-		
-		if (cfg.bridge0.configured) {
-			printf("Shutting down %s\n", cfg.bridge0.devsandbox);
-			net_if_down( cfg.bridge0.devsandbox);
-		}
-		if (cfg.bridge1.configured) {
-			printf("Shutting down %s\n", cfg.bridge1.devsandbox);
-			net_if_down( cfg.bridge1.devsandbox);
-		}
-		if (cfg.bridge2.configured) {
-			printf("Shutting down %s\n", cfg.bridge2.devsandbox);
-			net_if_down( cfg.bridge2.devsandbox);
-		}
-		if (cfg.bridge3.configured) {
-			printf("Shutting down %s\n", cfg.bridge3.devsandbox);
-			net_if_down( cfg.bridge3.devsandbox);
-		}
-		usleep(20000);	// 20 ms sleep
-	}	
-#endif	
 }
 
 
 static void start_application(void) {
+	// set environment
+	env_defaults();
+	env_apply();
+	if (arg_debug) {
+		printf("starting application\n");
+		printf("LD_PRELOAD=%s\n", getenv("LD_PRELOAD"));
+	}
+	
 	//****************************************
 	// start the program without using a shell
 	//****************************************
@@ -355,9 +338,6 @@ int sandbox(void* sandbox_arg) {
 #ifdef HAVE_CHROOT		
 	if (cfg.chrootdir) {
 		fs_chroot(cfg.chrootdir);
-		// redo cp command
-		fs_build_cp_command();
-		
 		// force caps and seccomp if not started as root
 		if (getuid() != 0) {
 			// force default seccomp inside the chroot, no keep or drop list
@@ -423,13 +403,21 @@ int sandbox(void* sandbox_arg) {
 	if (arg_private_dev)
 		fs_private_dev();
 	if (arg_private_etc) {
-		fs_private_etc_list();
-		// create /etc/ld.so.preload file again
-		if (arg_trace || arg_tracelog)
-			fs_trace_preload();
+		if (cfg.chrootdir)
+			fprintf(stderr, "Warning: private-etc feature is disabled in chroot\n");
+		else {
+			fs_private_etc_list();
+			// create /etc/ld.so.preload file again
+			if (arg_trace || arg_tracelog)
+				fs_trace_preload();
+		}
+	}
+	if (arg_private_bin) {
+		if (cfg.chrootdir)
+			fprintf(stderr, "Warning: private-bin feature is disabled in chroot\n");
+		else
+			fs_private_bin_list();
 	}
-	if (arg_private_bin)
-		fs_private_bin_list();
 	if (arg_private_tmp)
 		fs_private_tmp();
 	
@@ -576,12 +564,6 @@ int sandbox(void* sandbox_arg) {
 		}
 	}
 	
-	// set environment
-	env_defaults();
-	
-	// set user-supplied environment variables
-	env_apply();
-
 	//****************************
 	// set security filters
 	//****************************
@@ -667,6 +649,7 @@ int sandbox(void* sandbox_arg) {
 	}
 
 	monitor_application(app_pid);	// monitor application
+	flush_stdin();
 	
 	return 0;
 }
