@@ -24,6 +24,10 @@
 #include <errno.h>
 #include <dirent.h>
 #include <grp.h>
+#include <ftw.h>
+#include <sys/ioctl.h>
+#include <termios.h>
+#include <sys/wait.h>
 
 #define MAX_GROUPS 1024
 // drop privileges
@@ -210,6 +214,53 @@ int copy_file(const char *srcname, const char *destname) {
 	return 0;
 }
 
+// return -1 if error, 0 if no error
+void copy_file_as_user(const char *srcname, const char *destname, uid_t uid, gid_t gid, mode_t mode) {
+	pid_t child = fork();
+	if (child < 0)
+		errExit("fork");
+	if (child == 0) {
+		// drop privileges
+		drop_privs(0);
+
+		// copy, set permissions and ownership
+		int rv = copy_file(srcname, destname); // already a regular user
+		if (rv)
+			fprintf(stderr, "Warning: cannot copy %s\n", srcname);
+		else {
+			if (chown(destname, uid, gid) == -1)
+				errExit("chown");
+			if (chmod(destname, mode) == -1)
+				errExit("chmod");
+		}
+		_exit(0);
+	}
+	// wait for the child to finish
+	waitpid(child, NULL, 0);
+}
+
+// return -1 if error, 0 if no error
+void touch_file_as_user(const char *fname, uid_t uid, gid_t gid, mode_t mode) {
+	pid_t child = fork();
+	if (child < 0)
+		errExit("fork");
+	if (child == 0) {
+		// drop privileges
+		drop_privs(0);
+
+		FILE *fp = fopen(fname, "w");
+		if (fp) {
+			fprintf(fp, "\n");
+			SET_PERMS_STREAM(fp, uid, gid, mode);
+			fclose(fp);
+		}
+		_exit(0);
+	}
+	// wait for the child to finish
+	waitpid(child, NULL, 0);
+}
+
+
 // return 1 if the file is a directory
 int is_dir(const char *fname) {
 	assert(fname);
@@ -442,6 +493,13 @@ void extract_command_name(int index, char **argv) {
 		char *tmp = strdup(ptr);
 		if (!tmp)
 			errExit("strdup");
+
+		// limit the command to the first '.'
+		char *ptr2 = tmp;
+		while (*ptr2 != '.' && *ptr2 != '\0')
+			ptr2++;
+		*ptr2 = '\0';
+			
 		free(cfg.command_name);
 		cfg.command_name = tmp;
 	}
@@ -615,3 +673,33 @@ void invalid_filename(const char *fname) {
 		exit(1);
 	}
 }
+
+static int remove_callback(const char *fpath, const struct stat *sb, int typeflag, struct FTW *ftwbuf) {
+	(void) sb;
+	(void) typeflag;
+	(void) ftwbuf;
+	
+	int rv = remove(fpath);
+	if (rv)
+		perror(fpath);
+
+	return rv;
+}
+
+
+int remove_directory(const char *path) {
+	// FTW_PHYS - do not follow symbolic links
+	return nftw(path, remove_callback, 64, FTW_DEPTH | FTW_PHYS);
+}
+
+void flush_stdin(void) {
+	if (isatty(STDIN_FILENO)) {
+		int cnt = 0;
+		ioctl(STDIN_FILENO, FIONREAD, &cnt);
+		if (cnt) {
+			if (!arg_quiet)
+				printf("Warning: removing %d bytes from stdin\n", cnt);
+			ioctl(STDIN_FILENO, TCFLSH, TCIFLUSH);
+		}
+	}
+}
